% For use with Matlab
% Copyright (C) 2019 -- Jérôme Mendes <jermendes@gmail.com> or <jermendes@isr.uc.pt>, Rui Araújo <rui@isr.uc.pt>
% Jérôme Mendes, Francisco Souza, Rui Araújo, and Saeid Rastegar. "Neo-fuzzy neuron learning using backfitting algorithm". Neural Computing and Application, 2018.
% The "GAM-ZOTS toolbox" comes with ABSOLUTELY NO WARRANTY;
% In case of publication of any application of this method, please, cite the work:
% Jérôme Mendes, Francisco Souza, Rui Araújo, and Saeid Rastegar.
% Neo-fuzzy neuron learning using backfitting algorithm.
% Neural Computing and Applications, 31(8):3609-3618, August 2019.
% DOI: https://doi.org/10.1007/s00521-017-3301-4
% http://www.isr.uc.pt/~jermendes/    ;     http://www.isr.uc.pt/~rui/

function [] = PlotMFs(x, resolution)
    %% Description
    % This function presents the plots of the membership functions of all
    % input variables
    %% Function inputs
    % x - Struct with all parameters of the neo-fuzzy
    % resolution - resolution of MFs plot

if ~exist('resolution')
    % if resolution does not exist
    resolution = 1000;
end

n_var = length( x ); % number of variables

for j=1:n_var
    
    figure
    
    n_MFs = size( x(j).Rules,1); % number of MFs for variable j
    
    universe = x(j).Limit(1) : ( x(j).Limit(2)+x(j).Limit(1) )/resolution : x(j).Limit(2); % x axis
    
    
    for i = 1:n_MFs % for each rule of variable j
        
        parameters(1,1) = x(j).Rules(i,1); % parameter a_{j,i};
        parameters(1,2) = x(j).Rules(i,2); % parameter b_{j,i};
        parameters(1,3) = x(j).Rules(i,3); % parameter c_{j,i};
        
        y = trimf(universe, parameters); % Triangular membership function values
        
        plot(universe,y); % plot of the membership function
        hold on;
        labels{i} = strcat('MF ', num2str(i)); % Save legend
        
    end
    
    legend(labels) % Figure legends
    
    title(sprintf('MFs of input variable x_{%d}', j)) % Figure title
    
end

end
